<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>UUID Extractor & URL Generator</title>
    
    <!-- Bootstrap Dark Theme -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <style>
        body {
            background-color: #121212;
            color: white;
        }
        .container {
            margin-top: 30px;
        }
        textarea {
            background-color: #1e1e1e;
            color: white;
            border: 1px solid #444;
            padding: 10px;
            width: 100%;
        }
        .btn-custom {
            background-color: #007bff;
            color: white;
            border: none;
        }
        .btn-custom:hover {
            background-color: #0056b3;
        }
        .nav-tabs .nav-link {
            color: white;
        }
        .nav-tabs .nav-link.active {
            background-color: #007bff;
            color: white;
            border: none;
        }
    </style>
    
    <script>
        function copyToClipboard(elementId) {
            var text = document.getElementById(elementId).value;
            navigator.clipboard.writeText(text).then(() => {
                alert("Copied to clipboard!");
            }).catch(err => {
                alert("Failed to copy: " + err);
            });
        }

        function pasteFromClipboard(elementId) {
            navigator.clipboard.readText().then(text => {
                document.getElementById(elementId).value = text;
            }).catch(err => {
                alert("Failed to paste: " + err);
            });
        }

        function setActiveTab(tabId) {
            document.getElementById('activeTab').value = tabId;
        }

        // Preserve the active tab after form submission
        document.addEventListener("DOMContentLoaded", function () {
            var activeTab = localStorage.getItem("activeTab");
            if (activeTab) {
                document.querySelectorAll('.nav-link').forEach(tab => {
                    tab.classList.remove('active');
                });
                document.querySelectorAll('.tab-pane').forEach(tabContent => {
                    tabContent.classList.remove('show', 'active');
                });

                document.getElementById(activeTab).classList.add('active');
                document.getElementById(activeTab.replace("-tab", "")).classList.add('show', 'active');
            }

            document.querySelectorAll('.nav-link').forEach(tab => {
                tab.addEventListener('click', function () {
                    localStorage.setItem("activeTab", this.id);
                });
            });
        });
    </script>
</head>
<body>

    <div class="container">
        <h2 class="text-center">📌 UUID Extractor & URL Generator</h2>

        <!-- Tabs Navigation -->
        <ul class="nav nav-tabs">
            <li class="nav-item">
                <a class="nav-link active" id="extractor-tab" data-bs-toggle="tab" href="#extractor" onclick="setActiveTab('extractor-tab')">UUID Extractor</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="generator-tab" data-bs-toggle="tab" href="#generator" onclick="setActiveTab('generator-tab')">UUID URL Generator</a>
            </li>
        </ul>

        <div class="tab-content mt-4">
            
            <!-- UUID Extractor Tab -->
            <div class="tab-pane fade show active" id="extractor">
                <h3>🛠 UUID Extractor</h3>
                <form method="post">
                    <input type="hidden" name="activeTab" id="activeTab" value="extractor-tab">
                    <label for="inputText" class="form-label">Enter text to extract UUIDs:</label>
                    <textarea id="inputText" name="inputText" rows="5" class="form-control"></textarea>
                    <br>
                    <button type="button" class="btn btn-secondary" onclick="pasteFromClipboard('inputText')">📋 Paste</button>
                    <button type="submit" class="btn btn-custom" name="extract">🔍 Extract UUIDs</button>
                </form>

                <?php
                if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["extract"])) {
                    $inputText = trim($_POST["inputText"]);
                    $pattern = '/[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}/';

                    preg_match_all($pattern, $inputText, $matches);

                    if (!empty($matches[0])) {
                        $uuidList = implode("\n", $matches[0]);
                        echo "<h4>📌 Extracted UUIDs:</h4>";
                        echo "<textarea id='uuidOutput' rows='5' class='form-control' readonly>$uuidList</textarea>";
                        echo "<br><button type='button' class='btn btn-custom' onclick=\"copyToClipboard('uuidOutput')\">📋 Copy</button>";
                    } else {
                        echo "<p class='text-warning'>⚠ No valid UUIDs found.</p>";
                    }
                }
                ?>
            </div>

            <!-- UUID URL Generator Tab -->
            <div class="tab-pane fade" id="generator">
                <h3>🔗 UUID URL Generator</h3>
                <form method="post">
                    <input type="hidden" name="activeTab" id="activeTab" value="generator-tab">
                    <label for="baseUrl" class="form-label">Enter Full Base URL:</label>
                    <textarea id="baseUrl" name="baseUrl" rows="3" class="form-control"></textarea>
                    <br>
                    <button type="button" class="btn btn-secondary" onclick="pasteFromClipboard('baseUrl')">📋 Paste</button>

                    <br><br>

                    <label for="uuidList" class="form-label">Enter UUID List (One Per Line):</label>
                    <textarea id="uuidList" name="uuidList" rows="5" class="form-control"></textarea>
                    <br>
                    <button type="button" class="btn btn-secondary" onclick="pasteFromClipboard('uuidList')">📋 Paste</button>

                    <br><br>

                    <button type="submit" class="btn btn-custom" name="generate">⚡ Generate URLs</button>
                </form>

                <?php
                if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["generate"])) {
                    echo "<script>localStorage.setItem('activeTab', 'generator-tab');</script>";
                    $baseUrl = trim($_POST["baseUrl"]);
                    $uuidList = explode("\n", trim($_POST["uuidList"]));
                    $generatedUrls = [];

                    foreach ($uuidList as $uuid) {
                        $uuid = trim($uuid);
                        if (!empty($uuid)) {
                            $newUrl = preg_replace('/s=[0-9a-fA-F-]+/', 's=' . $uuid, $baseUrl);
                            $generatedUrls[] = $newUrl;
                        }
                    }

                    if (!empty($generatedUrls)) {
                        $outputText = implode("\n", $generatedUrls);
                        echo "<h4>📌 Generated URLs:</h4>";
                        echo "<textarea id='outputText' rows='8' class='form-control' readonly>$outputText</textarea>";
                        echo "<br><button type='button' class='btn btn-custom' onclick=\"copyToClipboard('outputText')\">📋 Copy</button>";
                    }
                }
                ?>
            </div>
        </div>
    </div>

</body>
</html>
